@@ -2,9 +2,11 @@
 
 import logging
 import os
+import re
 import subprocess
 import sys
 from pathlib import Path
+from typing import Optional
 
 import click
 
@@ -40,7 +42,7 @@ def git_config(option: str) -> str:
     """
     Return a git config value.
     """
-    return run_simple_command("git config --get {}".format(option))
+    return run_simple_command(f"git config --get {option}")
 
 
 def git_config_bool(option: str) -> bool:
@@ -50,25 +52,19 @@ def git_config_bool(option: str) -> bool:
     return git_config(option) == "true"
 
 
-def git_editor() -> str:
-    """
-    Get the command name of the editor Git will launch.
-    """
-    return run_simple_command("git var GIT_EDITOR")
-
-
 def git_edit(filename: Path) -> None:
     """Edit a file using the same editor Git chooses."""
-    click.edit(filename=str(filename), editor=git_editor())
+    git_editor = run_simple_command("git var GIT_EDITOR")
+    click.edit(filename=str(filename), editor=git_editor)
 
 
 def git_add(filename: Path) -> None:
     """Git add a file. If it fails, sys.exit."""
     ret = subprocess.call(["git", "add", str(filename)])
     if ret == 0:
-        logger.info("Added {}".format(filename))
+        logger.info(f"Added {filename}")
     else:
-        logger.error("Couldn't add {}".format(filename))
+        logger.error(f"Couldn't add {filename}")
         sys.exit(ret)
 
 
@@ -76,7 +72,30 @@ def git_rm(filename: Path) -> None:
     """Git rm a file. If it fails, sys.exit."""
     ret = subprocess.call(["git", "rm", str(filename)])
     if ret == 0:
-        logger.info("Removed {}".format(filename))
+        logger.info(f"Removed {filename}")
     else:
-        logger.error("Couldn't remove {}".format(filename))
+        logger.error(f"Couldn't remove {filename}")
         sys.exit(ret)
+
+
+def get_github_repo() -> Optional[str]:
+    """
+    Find the GitHub name/repo for this project.
+
+    If there is no remote on GitHub, or more than one, return None.
+    """
+    urls = run_simple_command(
+        r"git config --get-regex 'remote\..*\.url'"
+    ).splitlines()
+    github_repos = []
+    for url in urls:
+        m = re.search(r"github.com[:/]([^/]+/[^/]+)", url)
+        if m:
+            repo = m[1]
+            # I think it always has .git appended..
+            if repo.endswith(".git"):  # pragma: no branch
+                repo = repo[:-4]
+            github_repos.append(repo)
+    if len(github_repos) == 1:
+        return github_repos[0]
+    return None
