@@ -5,8 +5,11 @@ import shlex
 import subprocess
 from typing import List, Tuple, Union
 
+# The return value of run_command.
+CmdResult = Tuple[bool, str]
 
-def run_command(cmd: Union[str, List[str]]) -> Tuple[bool, str]:
+
+def run_command(cmd: Union[str, List[str]]) -> CmdResult:
     """
     Run a command line (with no shell).
 
@@ -15,9 +18,9 @@ def run_command(cmd: Union[str, List[str]]) -> Tuple[bool, str]:
         str: the output of the command.
 
     """
-    logging.debug("Running command {!r}".format(cmd))
+    logging.debug(f"Running command {cmd!r}")
     if isinstance(cmd, str):
-        cmd = shlex.split(cmd)
+        cmd = shlex.split(cmd, posix=False)
     proc = subprocess.run(
         cmd,
         shell=False,
@@ -27,9 +30,7 @@ def run_command(cmd: Union[str, List[str]]) -> Tuple[bool, str]:
     )
     output = proc.stdout.decode("utf-8")
     logging.debug(
-        "Command exited with {} status. Output: {!r}".format(
-            proc.returncode, output
-        )
+        f"Command exited with {proc.returncode} status. Output: {output!r}"
     )
 
     return proc.returncode == 0, output
